@@ -3,17 +3,13 @@ require "delayer/version"
 require "delayer/error"
 require "delayer/extend"
 require "delayer/procedure"
-require "delayer/priority"
+require "delayer/delayed_procedure"
 require "monitor"
 
 module Delayer
   class << self
     attr_accessor :default
 
-    def included(klass)
-      klass.extend Extend
-    end
-
     # Generate new Delayer class.
     # ==== Args
     # [options]
@@ -24,38 +20,25 @@ module Delayer
     # ==== Return
     # A new class
     def generate_class(options = {})
-      if options[:priority]
-        Class.new do
-          include Priority
-          @expire = options[:expire] || 0
+      Class.new do
+        include ::Delayer
+        @expire = options[:expire] || 0
+        if options.has_key?(:priority)
           @priorities = options[:priority]
           @default_priority = options[:default]
-        end
-      else
-        Class.new do
-          include ::Delayer
-          @expire = options[:expire] || 0
+        else
+          @priorities = [:normal]
+          @default_priority = :normal
         end
       end
     end
 
-    def method_missing(*args, &proc)
-      (@default ||= generate_class).__send__(*args, &proc)
+    def method_missing(*args, **kwrest, &proc)
+      if kwrest.empty?
+        (@default ||= generate_class).__send__(*args, &proc)
+      else
+        (@default ||= generate_class).__send__(*args, **kwrest, &proc)
+      end
     end
   end
-
-  def initialize(*args)
-    super
-    @procedure = Procedure.new(self, &Proc.new)
-  end
-
-  # Cancel this job
-  # ==== Exception
-  # Delayer::AlreadyExecutedError :: if already called run()
-  # ==== Return
-  # self
-  def cancel
-    @procedure.cancel
-    self
-  end
 end
