@@ -19,10 +19,14 @@ module Delayer
     end
   end
 
-  def initialize(priority = self.class.instance_eval { @default_priority }, *_args, &proc)
+  def initialize(priority = self.class.instance_eval { @default_priority }, *_args, delay: 0, &proc)
     self.class.validate_priority priority
     @priority = priority
-    @procedure = Procedure.new(self, &proc)
+    if delay == 0
+      @procedure = Procedure.new(self, &proc)
+    else
+      @procedure = DelayedProcedure.new(self, delay: delay, &proc)
+    end
   end
 
   # Cancel this job
@@ -46,8 +50,22 @@ module Delayer
         @remain_hook = nil
         @exception = nil
         @remain_received = false
-        @lock = Mutex.new
+        @lock = Monitor.new
         @bucket = Bucket.new(nil, nil, {}, nil)
+        @last_reserve = nil
+        @reserves = Set.new
+      end
+    end
+
+    def pop_reserve(start_time = Process.clock_gettime(Process::CLOCK_MONOTONIC))
+      if @last_reserve&.reserve_at&.<=(start_time)
+        lock.synchronize do
+          while @last_reserve&.reserve_at&.<=(start_time)
+            @last_reserve.register
+            @last_reserve = @reserves.min
+            @reserves.delete(@last_reserve)
+          end
+        end
       end
     end
 
@@ -57,11 +75,13 @@ module Delayer
     # ==== Return
     # self
     def run(current_expire = @expire)
+      start_time = Process.clock_gettime(Process::CLOCK_MONOTONIC)
+      pop_reserve(start_time)
       if current_expire == 0
-        run_once until empty?
+        run_once_without_pop_reserve until empty?
       else
-        @end_time = Time.new.to_f + @expire
-        run_once while !empty? && (@end_time >= Time.new.to_f)
+        @end_time = start_time + @expire
+        run_once_without_pop_reserve while !empty? && (@end_time >= Process.clock_gettime(Process::CLOCK_MONOTONIC))
         @end_time = nil
       end
       if @remain_hook
@@ -85,6 +105,11 @@ module Delayer
     # ==== Return
     # self
     def run_once
+      pop_reserve
+      run_once_without_pop_reserve
+    end
+
+    private def run_once_without_pop_reserve
       if @bucket.first
         @busy = true
         procedure = forward
@@ -146,6 +171,29 @@ module Delayer
       self
     end
 
+    # Register reserved job.
+    # It does not execute immediately.
+    # it calls register() in _procedure.reserve_at_.
+    # ==== Args
+    # [procedure] job(Delayer::DelayedProcedure)
+    # ==== Return
+    # self
+    def reserve(procedure)
+      lock.synchronize do
+        if @last_reserve
+          if @last_reserve > procedure
+            @reserves.add(@last_reserve)
+            @last_reserve = procedure
+          else
+            @reserves.add(procedure)
+          end
+        else
+          @last_reserve = procedure
+        end
+      end
+      self
+    end
+
     def register_remain_hook(&proc)
       @remain_hook = proc
     end
